Option Strict Off

Module modDrawing

    'set defaults for child form
    Public m_LeftPos As Integer = 5
    Public m_TopPos As Integer = 5
    Public m_Width As Integer = 256
    Public m_Height As Integer = 256
    Public m_ChildColor As String = "White"
    Public m_SurfaceBackground As String = "White"

    'set a reference to a graphics object to be used globally
    Public m_myGraphics As Graphics

    'set a reference to the child form to be used by the application
    Public m_myChild As frmChild

    Public Sub draw( _
        ByVal shape As String, _
        ByVal width As Integer, _
        ByVal height As Integer, _
        ByVal x As Integer, _
        ByVal y As Integer, _
        ByVal fillType As String, _
        ByVal outlineWeight As Single, _
        ByVal outlineColor As String, _
        ByVal solidColor As String, _
        ByVal blendFrom As String, _
        ByVal blendTo As String, _
        ByVal pattern As String, _
        ByVal patternForeColor As String, _
        ByVal patternBackColor As String, _
        ByVal blendStyle As String, _
        ByVal rotateAngle As Single)

        'purpose: draw a shape to the drawing surface (frmChild)

        'local scope
        Dim myPen As Pen
        Dim myRectangle As Rectangle
        Dim myBrush As Brush
        Dim myHatchStyle As Drawing2D.HatchStyle
        Dim myType As System.Type
        Dim myBlendStyle As Drawing2D.LinearGradientMode
        Dim myState As Drawing2D.GraphicsState

        'get the current state of the graphics object (pre-tranform)
        myState = m_myGraphics.Save()

        'set the rotation transformation value
        m_myGraphics.RotateTransform(angle:=rotateAngle)

        'check what shape to draw
        Select Case shape
            Case "Line"

                'create a new pen instance
                myPen = New Pen(color.FromName(name:=outlineColor), _
                    width:=outlineWeight)

                'draw the line to the surface
                m_myGraphics.DrawLine(pen:=myPen, x1:=x, y1:=y, _
                    x2:=x + width, y2:=y + height)

            Case "Rectangle", "Ellipse"

                'note: the rectangle and ellipse are vary similar 
                '      they can use the same code

                'create a new pen myect for the outline of the shape
                myPen = New Pen(color.FromName(name:=outlineColor), _
                    width:=outlineWeight)

                'create the rectangle object
                myRectangle = New Rectangle(x:=x, y:=y, width:=width, _
                    height:=height)

                'draw the rectangle to the surface
                If shape = "Ellipse" Then

                    'draw the ellipse
                    m_myGraphics.DrawEllipse(pen:=myPen, _
                        rect:=myRectangle)

                Else

                    'draw a rectangle
                    m_myGraphics.DrawRectangle(pen:=myPen, _
                        rect:=myRectangle)

                End If

                'fill the rectangle/ellipse
                If fillType <> "NONE" Then

                    'determine brush type to create
                    Select Case fillType
                        Case "SOLID"

                            'create a new solid brush
                            myBrush = New SolidBrush( _
                                color:=color.FromName(name:=solidColor))

                        Case "PATTERN"

                            'create the hatch brush
                            'note:  we use the type object and the parse 
                            '       method of the enum to return the 
                            '       value of the enum's member from a its 
                            '       name (string)
                            myType = myHatchStyle.GetType()
                            myBrush = New System.Drawing.Drawing2D.HatchBrush _
                            (myHatchStyle.Parse(enumType:=myType, _
                                value:=pattern), _
                                foreColor:=Color.FromName(name:=patternForeColor), _
                                backColor:=color.FromName(name:=patternBackColor))

                        Case "BLEND"

                            'create a blend brush
                            'note:  we use the type object and the parse 
                            '       method of the enum to return the 
                            '       value of the enum's member from a its 
                            '       name (string)
                            myType = myBlendStyle.GetType
                            myBrush = New System.Drawing.Drawing2D.LinearGradientBrush( _
                                rect:=myRectangle, _
                                color1:=color.FromName(name:=blendFrom), _
                                color2:=color.FromName(name:=blendTo), _
                                LinearGradientMode:=myBlendStyle.Parse( _
                                enumType:=myType, value:=blendStyle))

                    End Select

                    'fill the shape
                    If shape = "Ellipse" Then

                        'draw the ellipse with the correct brush
                        m_myGraphics.FillEllipse(brush:=myBrush, _
                            rect:=myRectangle)

                    Else

                        'fill the rectangle with the correct brush
                        m_myGraphics.FillRectangle(brush:=myBrush, _
                            rect:=myRectangle)

                    End If

                End If

        End Select

        'reset the state of the graphics object
        m_myGraphics.Restore(myState)

    End Sub

End Module
